@@ -10,15 +10,15 @@ use WWW::OpenResty::Simple;
 use Getopt::Std;
 
 my %opts;
-getopts('u:p:', \%opts) or
-    die "Usage: ./init.pl -u <user> -p <password>\n";
+getopts('u:p:s:', \%opts) or
+    die "Usage: ./csv2resty.pl -u <user> -p <password> -s <server>\n";
 
 my $user = $opts{u} or die "No -u specified.\n";
 my $password = $opts{p} or die "No -p specified.\n";
-
+my $server = $opts{s} or die "No -s specified.\n";
 
 my $resty = WWW::OpenResty::Simple->new(
-    { server => 'api.openresty.org' }
+    { server => $server }
 );
 $resty->login($user, $password);
 
@@ -31,10 +31,10 @@ while (<>) {
     next if $. == 1;
     chomp;
     my @cols = split /,/;
-    my ($name_pinyin, $name, $id, $department, $email, $office_phone, $cellphone, $im_id)
+    my ($name_pinyin, $name, $id, $department, $email, $office_phone, $cellphone, $im_id, $pos, $sex, $place)
         = @cols;
     my $row = {};
-    for my $key (qw< name_pinyin name employee_id department email office_phone cellphone yahoo_im_id>) {
+    for my $key (qw< name_pinyin name employee_id department email office_phone cellphone yahoo_im_id position gender workplace>) {
         my $value = shift @cols;
         $row->{$key} = $value;
     }
