@@ -2,8 +2,10 @@
 
 use strict;
 use warnings;
+use Encode qw(from_to);
 
 my $html = do { local $/; <> };
+from_to($html, 'gbk', 'utf8');
 $html =~ s/\&nbsp;/ /gs;
 $html =~ s/\&lt;/</gs;
 $html =~ s/\&gt;/>/gs;
